# pySLAMMER

pySLAMMER: **Py**thon package for **S**eismic **LA**ndslide **M**ovement **M**odeled using **E**arthquake **R**ecords
is a tool for estimating the co-seismic displacements of landslides with rigid and flexible sliding-block analyses.
The package name and code are based on the USGS tool [SLAMMER](https://pubs.usgs.gov/tm/12b1/)[^1].

Please see the [documentation](https://pyslammer.github.io/pySLAMMER_docs/) for information on how to install and use pySLAMMER.

## How to cite
Please include citations for both the pySLAMMER code and marker paper if you use pySLAMMER.

**Code:**

Arnold, L., & Garcia-Rivas, D. (2025). Pyslammer (Version v0.2.1) [Python]. Zenodo. https://doi.org/10.5281/zenodo.15385356

**Marker paper:**

*Pending (manuscript in review)*


[^1]: Jibson, R.W., Rathje, E.M., Jibson, M.W., and Lee, Y.W., 2013, SLAMMER—Seismic LAndslide Movement Modeled using Earthquake Records (ver.1.1, November 2014): U.S. Geological Survey Techniques and Methods, book 12, chap. B1, unpaged. https://pubs.usgs.gov/tm/12b1/
